Class: HTTPClient
- Inherits:
-
Object
- Object
- HTTPClient
- Defined in:
- lib/ingenico/connect/sdk/defaultimpl/default_connection.rb
Instance Method Summary collapse
-
#session_count ⇒ Object
(monkey) patch to gain access to the session pool size in HTTPClient.
Instance Method Details
#session_count ⇒ Object
(monkey) patch to gain access to the session pool size in HTTPClient
8 9 10 11 |
# File 'lib/ingenico/connect/sdk/defaultimpl/default_connection.rb', line 8 def session_count sess_pool = @session_manager.instance_variable_get(:@sess_pool) sess_pool.size end |