Class: Worldline::Connect::SDK::Logging::CommunicatorLogger

Inherits:
Object
  • Object
show all
Defined in:
lib/worldline/connect/sdk/logging/communicator_logger.rb

Overview

Base logger class used in this SDK. This class is an interface and cannot be instantiated.

Instance Method Summary collapse

Constructor Details

#initializeCommunicatorLogger

Interface, no instantiation



11
12
13
# File 'lib/worldline/connect/sdk/logging/communicator_logger.rb', line 11

def initialize
  raise NotImplementedError.new("#{self.class.name} is not implemented.")
end

Instance Method Details

#log(message, thrown = nil) ⇒ Object

Logs a message with or without exception

Parameters:

  • the message to log

  • (defaults to: nil)

    the exception to log, or nil to log no exception

Raises:



19
20
21
# File 'lib/worldline/connect/sdk/logging/communicator_logger.rb', line 19

def log(message, thrown = nil)
  raise NotImplementedError.new("#{self.class.name}#log() is not implemented.")
end